@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.db import models
+from djangoldp_conversation.models import Conversation, Message
 from djangoldp.models import Model
 from django.contrib.auth import get_user_model
 
@@ -32,10 +33,12 @@ class Resource (Model):
     img = models.URLField(default="/media/defaultresource.png", verbose_name="Illustration")
     document = models.URLField(blank=True, null=True, verbose_name="Document")
     link = models.CharField(max_length=150, blank=True, null=True, verbose_name="Internet link")
+    conversations = models.ManyToManyField(Conversation, blank=True, related_name='resources')
+
 
     class Meta : 
         serializer_fields=["@id", "name", "shortdesc", "longdesc", "type", "img", "document",\
-                           "link", "keywords"]
+                           "link", "keywords", "conversations"]
         auto_author = 'user'
         owner_field = 'user'
         container_path = 'resources/'
@@ -43,7 +46,7 @@ class Resource (Model):
         anonymous_perms = ['view', 'add']
         owner_perms = ['inherit', 'change', 'control', 'delete']
         authenticated_perms = ['inherit', 'add']
-        nested_fields = ['keywords']
+        nested_fields = ['keywords', 'conversations']
         
     def __str__(self):
         return self.name
\ No newline at end of file
